==> apache-cassandra-4.0.19-src.tar.gz: apache-cassandra-4.0.19-src/tools/stress/src/org/apache/cassandra/stress/report/Timer.java <==
package org.apache.cassandra.stress.report;
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */


import org.apache.cassandra.stress.StressAction.MeasurementSink;

// a timer - this timer must be used by a single thread, and co-ordinates with other timers by
public final class Timer
{
    private final String opType;
    private final MeasurementSink sink;

    // event timing info
    private long intendedTimeNs;
    private long startTimeNs;

    public Timer(String opType, MeasurementSink sink)
    {
        this.opType = opType;
        this.sink = sink;
    }


    public void stop(long partitionCount, long rowCount, boolean error)
    {
        sink.record(opType, intendedTimeNs, startTimeNs, System.nanoTime(), rowCount, partitionCount, error);
        resetTimes();
    }

    private void resetTimes()
    {
        intendedTimeNs = startTimeNs = 0;
    }

    public void intendedTimeNs(long v)
    {
        intendedTimeNs = v;
    }

    public void start()
    {
        startTimeNs = System.nanoTime();
    }
}

==> apache-cassandra-4.1.10-src.tar.gz: apache-cassandra-4.1.10-src/tools/stress/src/org/apache/cassandra/stress/report/Timer.java <==
package org.apache.cassandra.stress.report;
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */


import org.apache.cassandra.stress.StressAction.MeasurementSink;

import static org.apache.cassandra.utils.Clock.Global.nanoTime;

// a timer - this timer must be used by a single thread, and co-ordinates with other timers by
public final class Timer
{
    private final String opType;
    private final MeasurementSink sink;

    // event timing info
    private long intendedTimeNs;
    private long startTimeNs;

    public Timer(String opType, MeasurementSink sink)
    {
        this.opType = opType;
        this.sink = sink;
    }


    public void stop(long partitionCount, long rowCount, boolean error)
    {
        sink.record(opType, intendedTimeNs, startTimeNs, nanoTime(), rowCount, partitionCount, error);
        resetTimes();
    }

    private void resetTimes()
    {
        intendedTimeNs = startTimeNs = 0;
    }

    public void intendedTimeNs(long v)
    {
        intendedTimeNs = v;
    }

    public void start()
    {
        startTimeNs = nanoTime();
    }
}
